@@ -1,6 +1,6 @@
 .RSprint <- function(arg="f"){
   mim.cmd("pf 12,8",look.nice=FALSE)
-  fvobj <- .mim.cmd.term(paste("RSprint ",arg),
+  fvobj <- mim.cmd(paste("RSprint ",arg),
                          look.nice=FALSE, return.look.nice=TRUE)
   fvobj <- paste(fvobj,collapse='');
   fvobj <- eval(parse(text=fvobj))
@@ -23,7 +23,7 @@
 }
 
 .RSmodel <- function(arg=NULL){
-  fvobj <- .mim.cmd.term(paste("RSmodel ",arg),
+  fvobj <- mim.cmd(paste("RSmodel ",arg),
                          look.nice=FALSE, return.look.nice=TRUE)
   if (length(grep("Error",fvobj))>0)
     stop("The model formula is invalid ", call.=FALSE)
@@ -39,7 +39,7 @@
 }
 
 .RSoptions <- function(){
-  fvobj <- .mim.cmd.term("RSoptions",
+  fvobj <- mim.cmd("RSoptions",
                          look.nice=FALSE, return.look.nice=TRUE)
   fvobj <- paste(fvobj,collapse='');
   value <- eval(parse(text=fvobj))
